#!/bin/sh

# these are required for jabbapylib

sudo pip install -U \
    html5lib \
    lxml \
    pil \
    psutil \
    pycurl \
    pytest \
    untangle \
    virtualenv \
    reddit \
    praw \
    bigfloat \
    cssselect
